UpdateCommand class

Inheritance

Constructors

UpdateCommand({required bool runGen, required bool isTest, required Config config, required Iterable<LocalizationPackage> packages})

Properties

config → Config
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isTest → bool
finalinherited
packages → Iterable<LocalizationPackage>
finalinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runGen → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited