BuildConfig class

Constructors

BuildConfig()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

binName → const String
downloadedPath → const String
initPath → const String
unusedPath → const String
updatedPath → const String
uploadedPath → const String