Config class

Constructors

Config({required Iterable<PackageConfig> packagesConfigs, required String projectId, required String token, required Iterable<String> locales, required String projectKey})

Properties

hashCode → int
The hash code for this object.
no setterinherited
locales → Iterable<String>
final
packagesConfigs → Iterable<PackageConfig>
final
projectId → String
final
projectKey → String
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setter
token → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited