LocalizationBuilder class

Constructors

LocalizationBuilder({required Iterable<LocalizationPackage> packages, required Iterable<String> allowedLocales})

Properties

allowedLocales → Iterable<String>
final
hashCode → int
The hash code for this object.
no setterinherited
packages → Iterable<LocalizationPackage>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildInit() → Iterable<LocalizationPackage>
buildUpdate() → UpdateResult
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited