DownloadedPackage class

Inheritance

Constructors

DownloadedPackage({required Iterable<String> allowedLocales})

Properties

arbDirPath → String
no setterinherited
arbDirRelativePath → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
localizationFiles ↔ Iterable<LocalizationFile>
latefinalinherited
name → String
finalinherited
path → String
finalinherited
prefix → String
no setterinherited
projectKey → String?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
templateFile → String
finalinherited

Methods

copyWith({String? arbDirRelativePath, String? path}) → LocalizationPackage
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited