LocalizationPackage class

Implementers

Constructors

LocalizationPackage({required String path, required String arbDirRelativePath, required String templateFile, required String name, String? projectKey, required Iterable<String> allowedLocales})

Properties

arbDirPath → String
no setter
arbDirRelativePath → String
final
hashCode → int
The hash code for this object.
no setterinherited
localizationFiles ↔ Iterable<LocalizationFile>
latefinal
name → String
final
path → String
final
prefix → String
no setter
projectKey → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
templateFile → String
final

Methods

copyWith({String? arbDirRelativePath, String? path}) → LocalizationPackage
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited