LocalizelyApi class

Constructors

LocalizelyApi({required String projectId, required String token})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
final

Methods

download(String path, {required String locale}) → Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
upload(String filePath, {required String locale, bool overwrite = false, bool reviewed = false, List<String> tagsAdded = const [], List<String> tagsUpdated = const []}) → Future

Operators

operator ==(Object other) → bool
The equality operator.
inherited